@@ -1,13 +1,14 @@
-"""Metadata for `Column` objects that can be accessed during runtime."""
+"""Metadata for ``Column`` objects that can be accessed during runtime."""
 from dataclasses import dataclass
 from typing import Dict, Optional
 
 
 @dataclass
 class ColumnMeta:
-    """Contains the metadata for a `Column`. Used as:
+    """Contains the metadata for a ``Column``. Used as:
 
     .. code-block:: python
+
         class A(Schema):
             a: Annotated[
                 Column[IntegerType],
@@ -20,5 +21,5 @@ class ColumnMeta:
     comment: Optional[str] = None
 
     def get_metadata(self) -> Optional[Dict[str, str]]:
-        """Returns the comment of this column."""
+        """Returns the metadata of this column."""
         return {"comment": self.comment} if self.comment else None
