@@ -1,4 +1,4 @@
-"""A representation of the `Schema` to be used by Delta Live Tables."""
+"""A representation of the ``Schema`` to be used by Delta Live Tables."""
 
 from typing import Optional, TypedDict
 
@@ -6,11 +6,12 @@ from pyspark.sql.types import StructType
 
 
 class DltKwargs(TypedDict):
-    """A representation of the `Schema` to be used by Delta Live Tables.
+    """A representation of the ``Schema`` to be used by Delta Live Tables.
 
     .. code-block:: python
-        @dlt.table(**DimPatient.get_dlt_kwargs())
-        def table_definition() -> DataSet[DimPatient]:
+
+        @dlt.table(**Person.get_dlt_kwargs())
+        def table_definition() -> DataSet[Person]:
             <your table definition here>
     """
 
